@@ -1,5 +1,5 @@
 # Placeholder for logging callbacks
 log <- function(fmt, ...){
-  if(interactive())
+  if(!is_rapache())
     cat(sprintf(paste0("[%s] ", fmt, "\n"), as.character(Sys.time()), ...))
 }
